==> haskell-gtk2hs-buildtools-0.13.5.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.5.0
id: gtk2hs-buildtools-0.13.5.0-I7xsYBmV1jgL3zPqlBdmST
key: gtk2hs-buildtools-0.13.5.0-I7xsYBmV1jgL3zPqlBdmST
license: GPL-2.0-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
abi: 45fcf921f6559e55d7d7d5bb1aa6f5a7
exposed: True
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
import-dirs: /usr/lib/ghc-8.6.5/site-local/gtk2hs-buildtools-0.13.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/gtk2hs-buildtools-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.5.0-I7xsYBmV1jgL3zPqlBdmST
depends:
    Cabal-2.4.0.1 array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashtables-1.2.3.2-1VWxaZNawBG9JmG4jTXd6E pretty-1.1.3.6
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.5.0-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.5.0
id: gtk2hs-buildtools-0.13.5.0-KeykJbDG5oI7vnL3p2KkrH
key: gtk2hs-buildtools-0.13.5.0-KeykJbDG5oI7vnL3p2KkrH
license: GPL-2.0-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
abi: d7753547d343614dbf36d5fb1235dce6
exposed: True
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
import-dirs: /usr/lib/ghc-8.6.5/site-local/gtk2hs-buildtools-0.13.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/gtk2hs-buildtools-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.5.0-KeykJbDG5oI7vnL3p2KkrH
depends:
    Cabal-2.4.0.1 array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashtables-1.2.3.3-FSnAYMtQsLB35R41On7TKK pretty-1.1.3.6
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
